# Contributing to PySprint

## Reporting issues

When reporting issues please include as much detail as possible about your
operating system, numpy, scipy, matplotlib, PyQt5 version and python version. Whenever possible,
please also include a brief, self-contained code/screenshot example that demonstrates the problem.
Pysprint has a built-in `print_info` function which holds all the relevant information. Use it as follows:

```python
import pysprint as ps
ps.print_info()
```

This outputs something like this:

```python
PYSPRINT ANALYSIS TOOL

        SYSTEM
----------------------
python     : 3.7.6.final.0
python-bits: 64
OS         : Windows
OS-release : 10
Version    : 10.0.18362
machine    : AMD64
processor  : Intel64 Family 6 Model 158 Stepping 9, GenuineIntel
byteorder  : little

      DEPENDENCY
----------------------
pysprint   : 0.12.0
numpy      : 1.18.4
scipy      : 1.4.1
matplotlib : 3.2.2
pandas     : 1.0.1
pytest     : 5.4.2
lmfit      : 1.0.1
numba      : 0.50.1
IPython    : 7.12.0

      ADDITIONAL
----------------------
Conda env  : False
IPython    : True
Spyder     : False
```

Make sure you include this in every issue.

## Contributing code

Thanks for your interest in contributing code to PySprint!

This repository is strongly connected to my thesis, and to avoid any kind of copyright issues contributing is rejected until 2021 July.
Later on - when it's released - contributing will be available.
